Niquests is an elegant and simple HTTP library for Python, built for human beings. Drop-in replacement for Requests. No longer under feature freeze. You are currently looking at the documentation of the development release.

### Useful Links

- Quickstart
- Advanced Usage
- API Reference
- Release History
- Contributors Guide

- Recommended Packages and Extensions

- Niquests @ GitHub
- Niquests @ PyPI
- Issue Tracker